@@ -14,7 +14,7 @@ def test_submit_command(convex_url, test_account):
     args = Mock()
 
     args.url = convex_url
-    args.keywords = test_account.export_to_mnemonic
+    args.keywords = test_account.key_pair.export_to_mnemonic
     args.keyfile = None
     args.keytext = None
     args.password = None
